pub enum HeaderKind {
Show 16 variants
Compression,
GuidDefined,
Disposable,
Pe32,
Pic,
Te,
DxeDepex,
Version,
UserInterface,
Compatibility16,
VolumeImage,
Freeform,
Raw,
PeiDepex,
MmDepex,
Unknown(u8),
}
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.