#[repr(packed)]
pub struct Header {
pub zero_vector: [u8; 16],
pub guid: Guid,
pub length: u64,
pub signature: [u8; 4],
pub attributes: u32,
pub header_length: u16,
pub checksum: u16,
pub reserved: [u8; 3],
pub revision: u8,
}
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.